@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "gravatarresolvurljobtest.h"
@@ -39,6 +26,8 @@ void GravatarResolvUrlJobTest::shouldHaveDefaultValue()
     QCOMPARE(job.hasGravatar(), false);
     QCOMPARE(job.pixmap().isNull(), true);
     QCOMPARE(job.useDefaultPixmap(), false);
+    QCOMPARE(job.useLibravatar(), false);
+    QCOMPARE(job.fallbackGravatar(), true);
 }
 
 void GravatarResolvUrlJobTest::shouldChangeValue()
@@ -51,6 +40,21 @@ void GravatarResolvUrlJobTest::shouldChangeValue()
     useDefaultPixmap = false;
     job.setUseDefaultPixmap(useDefaultPixmap);
     QCOMPARE(job.useDefaultPixmap(), useDefaultPixmap);
+
+    bool useLibravatar = true;
+    job.setUseLibravatar(useLibravatar);
+    QCOMPARE(job.useLibravatar(), useLibravatar);
+
+    useLibravatar = false;
+    job.setUseLibravatar(useLibravatar);
+    QCOMPARE(job.useLibravatar(), useLibravatar);
+
+    bool fallBackGravatar = false;
+    job.setFallbackGravatar(fallBackGravatar);
+    QCOMPARE(job.fallbackGravatar(), fallBackGravatar);
+    fallBackGravatar = true;
+    job.setFallbackGravatar(fallBackGravatar);
+    QCOMPARE(job.fallbackGravatar(), fallBackGravatar);
 }
 
 void GravatarResolvUrlJobTest::shouldChangeSize()
@@ -81,8 +85,12 @@ void GravatarResolvUrlJobTest::shouldAddSizeInUrl()
     Gravatar::GravatarResolvUrlJob job;
     job.setEmail(QStringLiteral("foo@kde.org"));
     job.setSize(1024);
-    QUrl url = job.generateGravatarUrl();
-    QCOMPARE(url, QUrl(QStringLiteral("https://secure.gravatar.com:443/avatar/89b4e14cf2fc6d426275c019c6dc9de6?d=404&s=1024")));
+    job.setUseLibravatar(false);
+    QUrl url = job.generateGravatarUrl(job.useLibravatar());
+    QCOMPARE(url, QUrl(QStringLiteral("https://secure.gravatar.com:/avatar/89b4e14cf2fc6d426275c019c6dc9de6?d=404&s=1024")));
+    job.setUseLibravatar(true);
+    url = job.generateGravatarUrl(job.useLibravatar());
+    QCOMPARE(url, QUrl(QStringLiteral("https://seccdn.libravatar.org:/avatar/89b4e14cf2fc6d426275c019c6dc9de6?d=404&s=1024")));
 }
 
 void GravatarResolvUrlJobTest::shouldUseDefaultPixmap()
@@ -91,8 +99,8 @@ void GravatarResolvUrlJobTest::shouldUseDefaultPixmap()
     job.setEmail(QStringLiteral("foo@kde.org"));
     job.setSize(1024);
     job.setUseDefaultPixmap(true);
-    QUrl url = job.generateGravatarUrl();
-    QCOMPARE(url, QUrl(QStringLiteral("https://secure.gravatar.com:443/avatar/89b4e14cf2fc6d426275c019c6dc9de6?s=1024")));
+    QUrl url = job.generateGravatarUrl(job.useLibravatar());
+    QCOMPARE(url, QUrl(QStringLiteral("https://secure.gravatar.com:/avatar/89b4e14cf2fc6d426275c019c6dc9de6?s=1024")));
 }
 
 void GravatarResolvUrlJobTest::shouldUseHttps()
@@ -100,8 +108,12 @@ void GravatarResolvUrlJobTest::shouldUseHttps()
     Gravatar::GravatarResolvUrlJob job;
     job.setEmail(QStringLiteral("foo@kde.org"));
     job.setSize(1024);
-    QUrl url = job.generateGravatarUrl();
-    QCOMPARE(url, QUrl(QStringLiteral("https://secure.gravatar.com:443/avatar/89b4e14cf2fc6d426275c019c6dc9de6?d=404&s=1024")));
+    job.setUseLibravatar(false);
+    QUrl url = job.generateGravatarUrl(job.useLibravatar());
+    QCOMPARE(url, QUrl(QStringLiteral("https://secure.gravatar.com:/avatar/89b4e14cf2fc6d426275c019c6dc9de6?d=404&s=1024")));
+    job.setUseLibravatar(true);
+    url = job.generateGravatarUrl(job.useLibravatar());
+    QCOMPARE(url, QUrl(QStringLiteral("https://seccdn.libravatar.org/avatar/89b4e14cf2fc6d426275c019c6dc9de6?d=404&s=1024")));
 }
 
 void GravatarResolvUrlJobTest::shouldNotStart()
@@ -124,10 +136,13 @@ void GravatarResolvUrlJobTest::shouldGenerateGravatarUrl_data()
     QTest::addColumn<QString>("input");
     QTest::addColumn<QString>("calculedhash");
     QTest::addColumn<QUrl>("output");
-    QTest::newRow("empty") << QString() << QString() << QUrl();
-    QTest::newRow("no domain") << QStringLiteral("foo") << QString() << QUrl();
+    QTest::addColumn<bool>("uselibravatar");
+    QTest::newRow("empty") << QString() << QString() << QUrl() << false;
+    QTest::newRow("no domain") << QStringLiteral("foo") << QString() << QUrl() << false;
     QTest::newRow("validemail") << QStringLiteral("foo@kde.org") << QStringLiteral("89b4e14cf2fc6d426275c019c6dc9de6")
-                                << QUrl(QStringLiteral("https://secure.gravatar.com:443/avatar/89b4e14cf2fc6d426275c019c6dc9de6?d=404"));
+                                << QUrl(QStringLiteral("https://secure.gravatar.com:/avatar/89b4e14cf2fc6d426275c019c6dc9de6?d=404")) << false;
+    QTest::newRow("validemaillibravatar") << QStringLiteral("foo@kde.org") << QStringLiteral("89b4e14cf2fc6d426275c019c6dc9de6")
+                                          << QUrl(QStringLiteral("https://seccdn.libravatar.org/avatar/89b4e14cf2fc6d426275c019c6dc9de6?d=404")) << true;
 }
 
 void GravatarResolvUrlJobTest::shouldGenerateGravatarUrl()
@@ -135,9 +150,11 @@ void GravatarResolvUrlJobTest::shouldGenerateGravatarUrl()
     QFETCH(QString, input);
     QFETCH(QString, calculedhash);
     QFETCH(QUrl, output);
+    QFETCH(bool, uselibravatar);
     Gravatar::GravatarResolvUrlJob job;
     job.setEmail(input);
-    QUrl url = job.generateGravatarUrl();
+    job.setUseLibravatar(uselibravatar);
+    QUrl url = job.generateGravatarUrl(job.useLibravatar());
     QCOMPARE(calculedhash, job.calculatedHash().hexString());
     QCOMPARE(url, output);
 }
